CREATESTRUCT class

Constructors

CREATESTRUCT(UINT dwExStyle, String lpszClass, String lpszName, int style, int x, int y, int cx, int cy, HWND? hwndParent, HMENU? hMenu, dynamic hInstance, dynamic lpCreateParams)

Properties

cx int
getter/setter pair
cy int
getter/setter pair
dwExStyle UINT
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hInstance ↔ dynamic
getter/setter pair
hMenu HMENU?
getter/setter pair
hwndParent HWND?
getter/setter pair
lpCreateParams ↔ dynamic
getter/setter pair
lpszClass String
getter/setter pair
lpszName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
style int
getter/setter pair
x int
getter/setter pair
y int
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited