TWndStyle class

Inheritance

Constructors

TWndStyle(CLASS_ID cid)

Properties

block String
no setterinherited
borderBox String
no setterinherited
classId CLASS_ID
finalinherited
flex String
no setterinherited
font String
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
inline String
no setterinherited
no_select String
no setterinherited
prefix String
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sheet CssStyleSheet
no setterinherited
softBorder String
no setterinherited

Methods

add(String ext, String data) → void
inherited
addFocusStyle([dynamic subClass = 'focus-within']) → void
inherited
addRule(String name, String data) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited